@@ -34,7 +34,6 @@
 #include <qpushbutton.h>
 #include <qstylefactory.h>
 #include <qapplication.h>
-#include <qlayout.h>
 #include "version.h"
 #include "settings.h"
 #include "menu.h"
@@ -463,24 +462,14 @@ void OptionWindow::init() {
  setUpdatesEnabled( TRUE );
 }
 
-
-/**
- This is called on attempt to close window.
- The window will delete itself
- @param e Close event (unused)
-*/
-void OptionWindow::closeEvent(__attribute__((unused)) QCloseEvent *e) {
- delete this;
-}
-
 /** default destructor */
 OptionWindow::~OptionWindow() {
+ guiPrintDbg(debug::DBG_DBG,"Options closing ...");
  globalSettings->saveWindow(this,"options"); 
  delete labels;
  delete items;
  delete list;
  opt=NULL;//No instance active now
- guiPrintDbg(debug::DBG_DBG,"Options closing ...");
 }
 
 /** applies look and feel settings from options
